"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  default: () => VitePluginGraphQLCodegen
});
module.exports = __toCommonJS(src_exports);
var import_cli = require("@graphql-codegen/cli");

// src/utils/fileMatchers.ts
var import_vite = require("vite");
var import_plugin_helpers = require("@graphql-codegen/plugin-helpers");
function isCodegenConfig(filePath, context) {
  if (!context.filepath)
    return false;
  return (0, import_vite.normalizePath)(filePath) === (0, import_vite.normalizePath)(context.filepath);
}
async function isGraphQLDocument(filePath, context) {
  const config = context.getConfig();
  if (!config.documents)
    return false;
  const normalized = (0, import_plugin_helpers.normalizeInstanceOrArray)(config.documents);
  const documents = await context.loadDocuments(normalized);
  if (!documents.length)
    return false;
  const paths = documents.map(({ location = "" }) => location).map(import_vite.normalizePath).filter(Boolean);
  if (!paths.length)
    return false;
  return paths.some((documentPath) => documentPath === (0, import_vite.normalizePath)(filePath));
}
async function isGraphQLSchema(filePath, context) {
  const config = context.getConfig();
  if (!config.schema)
    return false;
  const schemas = (0, import_plugin_helpers.normalizeInstanceOrArray)(config.schema);
  const paths = schemas.filter((schema) => typeof schema === "string").map(import_vite.normalizePath).filter(Boolean);
  if (!paths.length)
    return false;
  return paths.some((schemaPath) => schemaPath === (0, import_vite.normalizePath)(filePath));
}

// src/utils/viteModes.ts
var modes = {
  serve: "serve",
  build: "build"
};
var isServeMode = (mode) => mode === modes.serve;
var isBuildMode = (mode) => mode === modes.build;

// src/utils/debugLog.ts
var RESET = "\x1B[0m";
var BRIGHT = "\x1B[1m";
var DIM = "\x1B[2m";
var FG_CYAN = "\x1B[36m";
function debugLog(...args) {
  const LOG_PREFIX = `${FG_CYAN}${BRIGHT}VITE PLUGIN GRAPHQL CODEGEN${RESET} `;
  console.log(LOG_PREFIX, DIM, ...args, RESET);
}

// src/index.ts
function VitePluginGraphQLCodegen(options) {
  let codegenContext;
  let viteMode;
  const {
    runOnStart = true,
    runOnBuild = true,
    enableWatcher = true,
    throwOnStart = false,
    throwOnBuild = true,
    matchOnDocuments = true,
    matchOnSchemas = false,
    config = null,
    configOverride = {},
    configOverrideOnStart = {},
    configOverrideOnBuild = {},
    configOverrideWatcher = {},
    configFilePathOverride,
    debug = false
  } = options ?? {};
  const log = (...args) => {
    if (!debug)
      return;
    debugLog(...args);
  };
  const generateWithOverride = async (overrideConfig) => {
    const currentConfig = codegenContext.getConfig();
    return (0, import_cli.generate)({
      ...currentConfig,
      ...configOverride,
      ...overrideConfig,
      // Vite handles file watching
      watch: false
    });
  };
  if (options)
    log("Plugin initialized with options:", options);
  return {
    name: "graphql-codegen",
    async config(_config, env) {
      try {
        if (config) {
          log("Manual config passed, creating codegen context");
          codegenContext = new import_cli.CodegenContext({ config });
        } else {
          const cwd = process.cwd();
          log("Loading codegen context:", configFilePathOverride ?? cwd);
          codegenContext = await (0, import_cli.loadContext)(configFilePathOverride);
        }
        log("Loading codegen context successful");
      } catch (error) {
        log("Loading codegen context failed");
        throw error;
      }
      viteMode = env.command;
    },
    async buildStart() {
      if (isServeMode(viteMode)) {
        if (!runOnStart)
          return;
        try {
          await generateWithOverride(configOverrideOnStart);
          log("Generation successful on start");
        } catch (error) {
          log("Generation failed on start");
          if (throwOnStart)
            throw error;
        }
      }
      if (isBuildMode(viteMode)) {
        if (!runOnBuild)
          return;
        try {
          await generateWithOverride(configOverrideOnBuild);
          log("Generation successful on build");
        } catch (error) {
          log("Generation failed on build");
          if (throwOnBuild)
            throw error;
        }
      }
    },
    configureServer(server) {
      if (!enableWatcher)
        return;
      const listener = async (filePath = "") => {
        log("File changed:", filePath);
        const isConfig = isCodegenConfig(filePath, codegenContext);
        if (isConfig) {
          log("Codegen config file changed, restarting vite");
          server.restart();
          return;
        }
        if (matchOnDocuments) {
          try {
            const isDocument = await isGraphQLDocument(
              filePath,
              codegenContext
            );
            log("Document check successful in file watcher");
            if (!isDocument)
              return;
            log("File matched a graphql document");
          } catch (error) {
            log("Document check failed in file watcher");
          }
        }
        if (matchOnSchemas) {
          try {
            const isSchema = await isGraphQLSchema(filePath, codegenContext);
            log("Schema check successful in file watcher");
            if (!isSchema)
              return;
            log("File matched a graphql schema");
          } catch (error) {
            log("Schema check failed in file watcher");
          }
        }
        try {
          await generateWithOverride(configOverrideWatcher);
          log("Generation successful in file watcher");
        } catch (error) {
          log("Generation failed in file watcher");
        }
      };
      server.watcher.on("add", listener);
      server.watcher.on("change", listener);
    }
  };
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {});
module.exports = module.exports.default;
//# sourceMappingURL=index.js.map